@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -15,5 +15,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-import mobius.model.application
-app = mobius.model.application.Application () 
+import mobius.application
+import mobius.model.mediator
+
+app = mobius.application.Application () 
+mediator = mobius.model.mediator.Mediator ()
