@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -46,12 +46,8 @@ class ResourceList (object):
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief add resource
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  def add (self, resource_id, resource, end_of_list=False):
-    if end_of_list:
-      self.__resource_ids.append (resource_id)
-    else:
-      self.__resource_ids.insert (0, resource_id)
-
+  def add (self, resource_id, resource):
+    self.__resource_ids.append (resource_id)
     self.__resources[resource_id] = resource
 
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -197,11 +193,13 @@ class Application (object):
   # @param resource_id: resource ID
   # @param resource: resource object
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  def svc_add_resource (self, resource_id, resource, end_of_list=False):
+  def svc_add_resource (self, resource_id, resource):
     if '.' in resource_id:
       group_id, item_id = resource_id.rsplit ('.', 1)
       resource_list = self.__resources.setdefault (group_id, ResourceList ())
-      resource_list.add (item_id, resource, end_of_list)
+      resource_list.add (item_id, resource)
+
+      mobius.mediator.emit ('app.resource-added', group_id, item_id, resource)
 
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief service: app.remove-resource
@@ -212,7 +210,9 @@ class Application (object):
       group_id, item_id = resource_id.rsplit ('.', 1)
       resource_list = self.__resources.setdefault (group_id, ResourceList ())
       resource_list.remove (item_id)
-  
+
+      mobius.mediator.emit ('app.resource-removed', group_id, item_id)
+
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief service: app.get-resource
   # @param resource_id: resource ID
